RawModeControl

Trait RawModeControl 

pub trait RawModeControl {
    // Required methods
    fn is_interactive(&self) -> bool;
    fn enable_raw_mode(&mut self) -> Result<()>;
    fn disable_raw_mode(&mut self) -> Result<()>;
}
Process-side terminal modes that cannot be expressed as terminal commands.

Output modes such as the alternate screen and input reporting are expressed by Command. Raw mode changes the process terminal driver and therefore remains a separate backend capability.

Required Methods

Implementations on Foreign Types

Source

impl<T: RawModeControl + ?Sized> RawModeControl for &mut T

Implementors